"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = withBooleanValue;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

/**
 * An enhancer that accepts a value prop, converts it to a boolean, and passes the boolean on to
 * the base component. The value 'true' is converted to true, and the value 'false' is converted
 * to false. Boolean values are passed directly to the base component.
 */
function withBooleanValue(BaseComponent) {
  function WithBooleanValue(props) {
    const {
      value,
      ...remainingProps
    } = props;
    let booleanValue;

    if (value === 'true') {
      booleanValue = true;
    } else if (value === 'false') {
      booleanValue = false;
    } else {
      booleanValue = value;
    }

    return /*#__PURE__*/_react.default.createElement(BaseComponent, _extends({
      value: booleanValue // eslint-disable-next-line react/jsx-props-no-spreading

    }, remainingProps));
  }

  WithBooleanValue.propTypes = { ...BaseComponent.propTypes,
    value: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.bool])
  };
  return WithBooleanValue;
}